close method
Closes the underlying Redis connection.
Implementation
Future<void> close() async {
// Note: The redis package doesn't provide a direct way to close the command stream here,
// but the connection is managed by the client.
}
Closes the underlying Redis connection.
Future<void> close() async {
// Note: The redis package doesn't provide a direct way to close the command stream here,
// but the connection is managed by the client.
}