core/config library

Classes

Config
A global configuration manager that loads and provides access to environment variables.

Typedefs

Env = Config
An alias for Config for backward compatibility and semantic preference.