AbortException class

Exception thrown to immediately terminate a request with a specific response.

Implemented types

Constructors

AbortException(Response response)
Creates a new AbortException with the given response.

Properties

hashCode → int
The hash code for this object.
no setterinherited
response → Response
The response to send.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited