elapsed property
Duration
get
elapsed
Returns the total elapsed time since the request was created.
Implementation
Duration get elapsed => _stopwatch.elapsed;
Returns the total elapsed time since the request was created.
Duration get elapsed => _stopwatch.elapsed;