resolve<T> method
Resolves an instance of type T from the request container.
Implementation
T resolve<T>({String? name}) => container.resolve<T>(name: name);
Resolves an instance of type T from the request container.
T resolve<T>({String? name}) => container.resolve<T>(name: name);