DefaultExceptionHandler class

The default global exception handler for Kronix.

Implemented types

Constructors

DefaultExceptionHandler()
Creates a new DefaultExceptionHandler.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Context ctx, Object error) Response
Renders a Response from the given error and ctx.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited