ExceptionHandler class abstract
Interface for classes that handle global exceptions in the framework.
- Implementers
Constructors
- ExceptionHandler()
- Internal constructor for ExceptionHandler.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Context ctx, Object error) → Response -
Renders a Response from the given
errorandctx. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited