RouteExplorer class

A utility to generate a document representation of all registered routes.

Constructors

RouteExplorer(App app)
Creates a new RouteExplorer for the given app.

Properties

app App
The application instance to explore.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

explore() List<Map<String, dynamic>>
Generates a List of Maps containing route details.
htmlHandler() Handler
Returns a Handler that renders a simple HTML explorer.
jsonHandler() Handler
Returns a Handler that renders the route information as JSON.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited