use method
Adds a middleware to the end of the pipeline.
Implementation
void use(Middleware middleware) {
_middlewares.add(middleware);
}
Adds a middleware to the end of the pipeline.
void use(Middleware middleware) {
_middlewares.add(middleware);
}