RouteNode class

A node in the routing trie.

Constructors

RouteNode(String segment)
Creates a new RouteNode for the given segment.

Properties

children Map<String, RouteNode>
Static children of this node.
final
dynamicChild RouteNode?
The child node for dynamic segments.
getter/setter pair
handlers Map<String, RouteData>
Handlers registered at this path, indexed by HTTP method.
final
hashCode int
The hash code for this object.
no setterinherited
paramName String?
The parameter name if this is a dynamic segment (e.g., "id" for ":id").
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segment String
The path segment this node represents.
final
wildcardChild RouteNode?
The child node for wildcard segments.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited