exceptionHandler property
The global exception handler used to transform errors into responses.
Implementation
ExceptionHandler exceptionHandler = DefaultExceptionHandler();
The global exception handler used to transform errors into responses.
ExceptionHandler exceptionHandler = DefaultExceptionHandler();