RuleHandler typedef
A function that validates a value against an optional argument and the full data map.
Implementation
typedef RuleHandler = FutureOr<bool> Function(dynamic value, String? arg, Map<String, dynamic> data);
A function that validates a value against an optional argument and the full data map.
typedef RuleHandler = FutureOr<bool> Function(dynamic value, String? arg, Map<String, dynamic> data);