Validator class

The core validation engine for the Kronix framework.

Constructors

Validator()
Internal constructor for Validator.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

ruleHandlers → Map<String, RuleHandler>
Registry of validation rules. Can be extended by users to add custom rules.
final

Static Methods

validate(Map<String, dynamic> data, Map<String, String> rules, [Map<String, String>? customMessages]) → Future<ValidationResult>
Validates the data against the provided rules.