id property
String
get
id
A unique identifier for this connection, identical to the initial Context.requestId.
Implementation
String get id => context.requestId;
A unique identifier for this connection, identical to the initial Context.requestId.
String get id => context.requestId;