emit method
Sends a message directly to a specific client by their clientId.
Implementation
void emit(String clientId, dynamic message) {
_connections[clientId]?.send(message);
}
Sends a message directly to a specific client by their clientId.
void emit(String clientId, dynamic message) {
_connections[clientId]?.send(message);
}