DatabaseAdapter class abstract

Abstract interface for database drivers.

Implemented types
Implementers

Constructors

DatabaseAdapter()
Internal constructor for DatabaseAdapter.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future<void>
Closes the database connection.
connect() → Future<void>
Establishes a connection to the database.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(String sql, [Map<String, dynamic>? params]) → Future<QueryResult>
Executes a raw sql query within this executor's scope.
inherited
table(String name, [DatabaseExecutor? executor]) → QueryBuilder
Returns a QueryBuilder for the specified name (table).
toString() → String
A string representation of this object.
inherited
transaction<T>(Future<T> callback(DatabaseExecutor tx)) → Future<T>
Executes multiple queries within a single transaction.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited