QueryResult class abstract

Represents the result of a database query execution.

Implementers

Constructors

QueryResult()
Internal constructor for QueryResult.

Properties

affectedRows → int?
The number of rows affected by an INSERT, UPDATE, or DELETE query.
no setter
hashCode → int
The hash code for this object.
no setterinherited
rows → List<Map<String, dynamic>>
The list of rows returned by the query, represented as Maps.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited