Migration class abstract

Base class for database schema migrations.

Implementing classes should define the up and down methods to apply and revert schema changes respectively.

Each migration is executed within a transaction by the migration runner. The provided DatabaseExecutor is the active transaction scope.

Constructors

Migration()
Internal constructor for Migration.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

down(DatabaseExecutor db) Future<void>
Reverts the schema changes within the given transaction scope.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
up(DatabaseExecutor db) Future<void>
Applies the schema changes within the given transaction scope.

Operators

operator ==(Object other) bool
The equality operator.
inherited