exists property
bool
get
exists
Whether this model has been persisted to the database.
Implementation
bool get exists => id != null;
Whether this model has been persisted to the database.
bool get exists => id != null;