setRawData method
Sets the database executor and raw attributes for this model instance.
Implementation
void setRawData(DatabaseExecutor executor, Map<String, dynamic> raw) {
_executor = executor;
_rawAttributes = raw;
}
Sets the database executor and raw attributes for this model instance.
void setRawData(DatabaseExecutor executor, Map<String, dynamic> raw) {
_executor = executor;
_rawAttributes = raw;
}