PostgresExecutor class

Implementation of DatabaseExecutor for PostgreSQL sessions/transactions.

Transactions are managed by the pool's run() scope:

  • Commit: Automatic when the callback completes successfully.
  • Rollback: Automatic when the callback throws an exception.
Implemented types

Constructors

PostgresExecutor(Session _session)
Creates a new PostgresExecutor wrapping the given session.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(String sql, [Map<String, dynamic>? params]) Future<QueryResult>
Executes a raw sql query within this executor's scope.
override
toString() String
A string representation of this object.
inherited
transaction<T>(Future<T> callback(DatabaseExecutor tx)) Future<T>
Executes multiple queries within a single transaction.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited