Schema constructor
Schema(
- DatabaseExecutor _db
Creates a new Schema tied to the given database executor.
Implementation
Schema(this._db);
Creates a new Schema tied to the given database executor.
Schema(this._db);