child method
Creates a child container that delegates to this one for missing services.
Implementation
Container child() => Container(parent: this);
Creates a child container that delegates to this one for missing services.
Container child() => Container(parent: this);