currentRetryDelay property
Calculates the delay for the current retry attempt using exponential backoff.
Implementation
Duration get currentRetryDelay {
final multiplier = 1 << (attempts - 1); // 1, 2, 4, 8, ...
return retryDelay * multiplier;
}
Calculates the delay for the current retry attempt using exponential backoff.
Duration get currentRetryDelay {
final multiplier = 1 << (attempts - 1); // 1, 2, 4, 8, ...
return retryDelay * multiplier;
}