timeout property

Duration? get timeout
inherited

Maximum time a single job execution is allowed to run.

If the job exceeds this duration, it will be cancelled and treated as a failure (eligible for retry). Set to null for no timeout.

Implementation

Duration? get timeout => const Duration(seconds: 60);