pop abstract method

Future<Job?> pop([
  1. String queue = 'default'
])

Pops the next available job from the queue atomically.

Implementations MUST guarantee that no two workers can receive the same job (distributed lock / atomic dequeue). Returns null if the queue is empty or no jobs are available.

Implementation

Future<Job?> pop([String queue = 'default']);