isAvailable property
bool
get
isAvailable
Returns true if this job is ready to be processed now.
Implementation
bool get isAvailable =>
availableAt == null || DateTime.now().isAfter(availableAt!);
Returns true if this job is ready to be processed now.
bool get isAvailable =>
availableAt == null || DateTime.now().isAfter(availableAt!);