Queue constructor
Queue({
- required QueueDriver driver,
Creates a new Queue instance with the given driver.
Implementation
Queue({required this.driver});
Creates a new Queue instance with the given driver.
Queue({required this.driver});