JobTimeoutException class

Exception thrown when a job exceeds its Job.timeout duration.

Implemented types

Constructors

JobTimeoutException(String jobId, String jobName, Duration timeout)
Creates a new JobTimeoutException.

Properties

hashCode int
The hash code for this object.
no setterinherited
jobId String
The unique ID of the job that timed out.
final
jobName String
The logical name of the job that timed out.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
The duration that was exceeded.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited