MemorySessionStore class

In-memory implementation of SessionStore.

Implemented types

Constructors

MemorySessionStore()
Creates a new MemorySessionStore.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

forget(String id) Future<void>
Deletes a session.
override
get(String id) Future<Map<String, dynamic>?>
Retrieves session data by ID.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String id, Map<String, dynamic> data, {Duration? ttl}) Future<void>
Saves session data.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited