TestClient class

A client for making fluent, functional requests to a Kronix App.

Constructors

TestClient(App app)
Creates a TestClient for the given app.

Properties

app App
The application instance being tested.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String path, {Map<String, String>? headers}) Future<TestResponse>
Makes a DELETE request to the given path.
get(String path, {Map<String, String>? headers}) Future<TestResponse>
Makes a GET request to the given path.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String path, {Map<String, String>? headers, dynamic body}) Future<TestResponse>
Makes a POST request with an optional body.
put(String path, {Map<String, String>? headers, dynamic body}) Future<TestResponse>
Makes a PUT request with an optional body.
stop() Future<void>
Stops the app.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited