AbortException class
Exception thrown to immediately terminate a request with a specific response.
- Implemented types
Constructors
- AbortException(Response response)
-
Creates a new AbortException with the given
response.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited