LogDriver class abstract

Interface for log destinations (e.g., console, file, external service).

Implementers

Constructors

LogDriver()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(LogRecord record) → void
Writes a record to the destination.

Operators

operator ==(Object other) bool
The equality operator.
inherited