MiddlewareHelper class
Utility class for middleware operations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
except(
String prefix, Middleware middleware) → Middleware -
Wraps a
middlewareto execute for all paths EXCEPT those starting withprefix. -
exceptMany(
List< String> paths, Middleware middleware) → Middleware -
Wraps a
middlewareto execute for all paths EXCEPT those in thepathslist. -
only(
String path, Middleware middleware) → Middleware -
Wraps a
middlewareto ONLY execute if the request path matchespath.