Pipeline class
Manages a sequence of Middleware functions and their execution order.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
exec(
Context ctx, Handler handler) → Future< Response> -
Executes the pipeline for the given
ctx, finishing with thehandler. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
use(
Middleware middleware) → void -
Adds a
middlewareto the end of the pipeline.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited