RouteNode class

Constructors

RouteNode(String segment)

Properties

children Map<String, RouteNode>
getter/setter pair
dynamicChild RouteNode?
getter/setter pair
handlers Map<String, RouteData>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
paramName String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segment String
getter/setter pair
wildcardChild RouteNode?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited