core/validator library
Classes
- FormRequest
- Interface for classes that define validation rules and messages.
- ValidationResult
- Result of a validation operation containing errors and coerced data.
- Validator
- The core validation engine for the Kronix framework.