FormRequest class abstract

Interface for classes that define validation rules and messages.

Constructors

FormRequest()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

messages() Map<String, String>
Returns a map of attribute.rule keys to custom error messages.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rules() Map<String, String>
Returns a map of field names to validation rule strings (e.g., 'required|email').
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited