ValidationResult class

Result of a validation operation containing errors and coerced data.

Constructors

ValidationResult(Map<String, List<String>> errors, Map<String, dynamic> data)
Creates a new ValidationResult.

Properties

data → Map<String, dynamic>
The validated and potentially coerced data.
final
errors → Map<String, List<String>>
A map of field names to lists of error messages.
final
fails → bool
Returns true if validation failed.
no setter
hashCode → int
The hash code for this object.
no setterinherited
passes → bool
Returns true if validation passed.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited