DatabaseExecutor class abstract
Interface for executing queries within a specific database scope.
- Implementers
Constructors
- DatabaseExecutor()
- Internal constructor for DatabaseExecutor.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
String sql, [Map< String, dynamic> ? params]) → Future<QueryResult> -
Executes a raw
sqlquery within this executor's scope. -
toString(
) → String -
A string representation of this object.
inherited
-
transaction<
T> (Future< T> callback(DatabaseExecutor tx)) → Future<T> - Executes multiple queries within a single transaction.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited