MigrationEntry class

Represents a single migration entry in the MigrationRunner registry.

Constructors

MigrationEntry(String name, Migration migration)
Creates a new MigrationEntry.

Properties

hashCode int
The hash code for this object.
no setterinherited
migration Migration
The migration instance to execute.
final
name String
The unique name of the migration (usually a timestamp prefix + title).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited