PostgresQueryResult class
Implementation of QueryResult for PostgreSQL.
- Implemented types
Constructors
-
PostgresQueryResult(List<
Map< rows, [int? affectedRows])String, dynamic> > - Creates a new PostgresQueryResult.
Properties
- affectedRows → int?
-
The number of rows affected by an INSERT, UPDATE, or DELETE query.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
rows
→ List<
Map< String, dynamic> > -
The list of rows returned by the query, represented as Maps.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited