ColumnDefinition class
Defines a single column in a Blueprint.
Supports chaining modifiers like nullable, unique, defaultsTo, and references.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
check(
String expression) → ColumnDefinition - Adds a CHECK constraint expression.
-
defaultsTo(
String expression) → ColumnDefinition - Sets a default value expression (raw SQL).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
nullable(
) → ColumnDefinition - Marks this column as nullable.
-
toString(
) → String -
A string representation of this object.
inherited
-
unique(
) → ColumnDefinition - Adds a UNIQUE constraint to this column.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited