Disposable class abstract

An interface for services that require explicit cleanup at the end of a lifecycle.

Implementing Disposable allows a service to perform asynchronous cleanup (e.g., closing database connections or clearing cache buffers) when the container is disposed.

Implementers

Constructors

Disposable()
Internal constructor for Disposable.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
Performs cleanup operations.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited