Storage class abstract
Abstract interface for file storage systems.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
String path) → Future< void> -
Deletes the file at
path. -
exists(
String path) → Future< bool> -
Checks if a file exists at
path. -
get(
String path) → Future< List< int> > -
Retrieves the content of the file at
pathas bytes. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
put(
String path, List< int> bytes) → Future<String> -
Stores the
bytesat the specifiedpath. -
putFile(
String targetPath, String localPath) → Future< String> -
Stores a file from the
localPathat the specifiedtargetPath. -
toString(
) → String -
A string representation of this object.
inherited
-
url(
String path) → String -
Returns a public URL for the file at
path.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited