RequestSizeLimit class

Middleware for enforcing a maximum size on incoming request bodies.

Constructors

RequestSizeLimit(int maxBytes)
Creates a new RequestSizeLimit with the specified maxBytes.

Properties

hashCode int
The hash code for this object.
no setterinherited
maxBytes int
The maximum allowed size in bytes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handle() Middleware
Returns a Middleware that rejects requests exceeding the size limit.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited