JobTimeoutException class

Exception thrown when a job exceeds its Job.timeout duration.

Implemented types

Constructors

JobTimeoutException(String jobId, String jobName, Duration timeout)

Properties

hashCode int
The hash code for this object.
no setterinherited
jobId String
final
jobName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited