SessionMiddleware class
Middleware for managing server-side sessions.
Constructors
- SessionMiddleware({required SessionStore store, String cookieName = 'kronix_session', Duration ttl = const Duration(hours: 2)})
- Creates a new SessionMiddleware instance.
Properties
-
The name of the session cookie.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- store → SessionStore
-
The storage engine used to persist session data.
final
- ttl → Duration
-
The time-to-live for sessions.
final
Methods
-
handle(
) → Middleware - Returns a Middleware that manages the session lifecycle.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited