TestClient class
A client for making fluent, functional requests to a Kronix App.
Constructors
- TestClient(App app)
-
Creates a TestClient for the given
app.
Properties
Methods
-
delete(
String path, {Map< String, String> ? headers}) → Future<TestResponse> -
Makes a
DELETErequest to the givenpath. -
get(
String path, {Map< String, String> ? headers}) → Future<TestResponse> -
Makes a
GETrequest to the givenpath. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
post(
String path, {Map< String, String> ? headers, dynamic body}) → Future<TestResponse> -
Makes a
POSTrequest with an optionalbody. -
put(
String path, {Map< String, String> ? headers, dynamic body}) → Future<TestResponse> -
Makes a
PUTrequest with an optionalbody. -
stop(
) → Future< void> - Stops the app.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited