TestClient class
A client for making fluent, functional requests to a Kronix App.
Constructors
- TestClient(App app)
Properties
Methods
-
delete(
String path, {Map< String, String> ? headers}) → Future<TestResponse> -
get(
String path, {Map< String, String> ? headers}) → Future<TestResponse> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
post(
String path, {Map< String, String> ? headers, dynamic body}) → Future<TestResponse> -
put(
String path, {Map< String, String> ? headers, dynamic body}) → Future<TestResponse> -
stop(
) → Future< void> - Stops the app.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited